pub(crate) fn close_subpaths<I>(elements: I) -> CloseSubpaths<I::IntoIter> ⓘwhere
I: IntoIterator<Item = PathEl>,Expand description
Close all open subpaths in a path, expressed as iterator transform.
pub(crate) fn close_subpaths<I>(elements: I) -> CloseSubpaths<I::IntoIter> ⓘwhere
I: IntoIterator<Item = PathEl>,Close all open subpaths in a path, expressed as iterator transform.